@@ -337,7 +337,7 @@ class Assets(WMLResource):
             (m[u'metadata'][u'name'], m[u'metadata'][u'asset_type'], m[u'metadata'][u'size'], m["metadata"]["asset_id"]) for
             m in asset_details]
 
-        self._list(space_values, [u'NAME', u'ASSET_TYPE', u'SIZE',u'ASSET_ID'], None, _DEFAULT_LIST_LENGTH)
+        self._list(space_values, [u'NAME', u'ASSET_TYPE', u'SIZE', u'ASSET_ID'], limit, _DEFAULT_LIST_LENGTH)
 
     @docstring_parameter({'str_type': STR_TYPE_NAME})
     def download(self, asset_uid, filename):
