@@ -61,6 +61,7 @@ import os
 
 class APIClient:
     version = None
+    _internal = False
 
     def __init__(self, wml_credentials, project_id=None, verify=None):
         self._logger = logging.getLogger(__name__)
@@ -140,11 +141,16 @@ class APIClient:
             self.ICP = False
             self.CAMS = False
 
-            if wml_credentials[u'url'] in self.PLATFORM_URLS_MAP.keys():
-                self.PLATFORM_URL = self.PLATFORM_URLS_MAP[wml_credentials[u'url']]
-                self.CAMS_URL = self.PLATFORM_URLS_MAP[wml_credentials[u'url']]
+            if self._internal:
+                self.PLATFORM_URL = wml_credentials[u'url']
+                self.CAMS_URL = wml_credentials[u'url']
+
             else:
-                raise WMLClientError(Messages.get_message(message_id="invalid_cloud_scenario_url"))
+                if wml_credentials[u'url'] in self.PLATFORM_URLS_MAP.keys():
+                    self.PLATFORM_URL = self.PLATFORM_URLS_MAP[wml_credentials[u'url']]
+                    self.CAMS_URL = self.PLATFORM_URLS_MAP[wml_credentials[u'url']]
+                else:
+                    raise WMLClientError(Messages.get_message(message_id="invalid_cloud_scenario_url"))
 
             if not self._is_IAM():
                 raise WMLClientError(Messages.get_message(message_id="apikey_not_provided"))
@@ -254,11 +260,16 @@ class APIClient:
                                 if not self._is_IAM():
                                     raise WMLClientError(Messages.get_message(message_id="apikey_not_provided"))
 
-                                if wml_credentials[u'url'] in self.PLATFORM_URLS_MAP.keys():
-                                    self.PLATFORM_URL = self.PLATFORM_URLS_MAP[wml_credentials[u'url']]
-                                    self.CAMS_URL = self.PLATFORM_URLS_MAP[wml_credentials[u'url']]
+                                if self._internal:
+                                    self.PLATFORM_URL = wml_credentials[u'url']
+                                    self.CAMS_URL = wml_credentials[u'url']
+
                                 else:
-                                    raise WMLClientError(Messages.get_message(message_id="url_not_provided"))
+                                    if wml_credentials[u'url'] in self.PLATFORM_URLS_MAP.keys():
+                                        self.PLATFORM_URL = self.PLATFORM_URLS_MAP[wml_credentials[u'url']]
+                                        self.CAMS_URL = self.PLATFORM_URLS_MAP[wml_credentials[u'url']]
+                                    else:
+                                        raise WMLClientError(Messages.get_message(message_id="url_not_provided"))
 
                                 if self.CLOUD_PLATFORM_SPACES:
                                     print(Messages.get_message(message_id="instance_id_is_not_required_for_v2_plans"))
@@ -316,6 +327,9 @@ class APIClient:
                     print(Messages.get_message(message_id="python_3_6_framework_is_deprecated"))
                 elif self.ICP_PLATFORM_SPACES:
                     print(Messages.get_message(message_id="python_3_6_framework_is_deprecated_cp4d"))
+            elif (3 == sys.version_info.major) and ((7 == sys.version_info.minor) or (8 == sys.version_info.minor)):
+                if self.CLOUD_PLATFORM_SPACES or self.ICP_PLATFORM_SPACES:
+                    print(Messages.get_message(message_id="python_3_7_3_8_framework_are_deprecated"))
 
             self.service_instance = ServiceInstanceNewPlan(self)
             self.volumes = Volume(self)
@@ -388,7 +402,6 @@ class APIClient:
             self.connections = Connections(self)
 
         self._logger.info(Messages.get_message(message_id="client_successfully_initialized"))
-        self.version = version()
 
     def _check_if_either_is_set(self):
         if self.CAMS or self.CLOUD_PLATFORM_SPACES:
@@ -421,15 +434,15 @@ class APIClient:
             else:
                 raise WMLClientError(Messages.get_message(message_id="it_is_mandatory_to_set_the_project_id"))
 
-        if self.project_type == 'local_git_storage':
+        if self.default_project_id and self.project_type == 'local_git_storage':
             params.update({'userfs': 'true'})
 
-        if self.project_type != 'local_git_storage' and 'userfs' in params:
+        if (not self.default_project_id or self.project_type != 'local_git_storage') and 'userfs' in params:
             del params['userfs']
 
         return params
 
-    def _get_headers(self, content_type='application/json', no_content_type=False, wsdconnection_api_req=False, zen=False):
+    def _get_headers(self, content_type='application/json', no_content_type=False, wsdconnection_api_req=False, zen=False, projects_token=False):
         if self.WSD:
                 headers = {'X-WML-User-Client': 'PythonClient'}
                 if self.project_id is not None:
@@ -444,10 +457,20 @@ class APIClient:
 
         elif zen:
             headers= {'Content-Type': content_type}
-            headers.update({'Authorization': "Bearer " + self.service_instance._create_token()})
+            token = self.service_instance._create_token()
+            if len(token.split('.')) == 1:
+                headers.update({'Authorization': "Basic " + token})
+
+            else:
+                headers.update({'Authorization': "Bearer " + token})
         else:
             if self.proceed is True:
-                token = "Bearer "+ self.wml_credentials["token"]
+                token_to_use = self.wml_credentials['projects_token'] if projects_token and 'projects_token' in self.wml_credentials else self.wml_credentials["token"]
+                if len(token_to_use.split('.')) == 1:
+                    token = "Basic " + token_to_use
+
+                else:
+                    token = "Bearer " + token_to_use
             else:
                 token = "Bearer " + self.service_instance._get_token()
             headers = {
