@@ -454,12 +454,13 @@ class Connections(WMLResource):
         else:
             header_param = self._client._get_headers()
 
-        sess = self.requests_retry_session()
-        response = sess.get(self._client.service_instance._href_definitions.get_connection_data_types_href(),
-                            headers=header_param)
+        with self.requests_retry_session() as sess:
+            response = sess.get(self._client.service_instance._href_definitions.get_connection_data_types_href(),
+                                headers=header_param)
+
+            datasource_id = 'None'
+            datasource_details = self._handle_response(200, u'list datasource types', response)['resources']
 
-        datasource_id = 'None'
-        datasource_details = self._handle_response(200, u'list datasource types', response)['resources']
         for i, ds_resource in enumerate(datasource_details):
             if ds_resource['entity']['name'] == name:
                 datasource_id = ds_resource['metadata']['asset_id']
