@@ -4,11 +4,12 @@ import os
 import pandas as pd
 
 from typing import Union, Optional
-
+from warnings import warn
 from ibm_watson_machine_learning.helpers.connections.flight_service import (
     FlightConnection,
 )
 from ibm_watson_machine_learning.helpers.connections.local import LocalBatchReader
+from ibm_watson_machine_learning.utils.autoai.enums import SamplingTypes
 
 # Note: try to import torch lib if available, this fallback is done based on
 # torch dependency removal request
@@ -40,10 +41,25 @@ class ExperimentIterableDataset(IterableDataset):
         >>> connection = DataConnection(data_asset_id='5d99c11a-2060-4ef6-83d5-dc593c6455e2')
 
 
+        >>># default sampling - read first 1GB of data
         >>> iterable_dataset = ExperimentIterableDataset(connection=connection,
-        >>>                                              with_subsampling=False,
-        >>>                                              experiment_metadata=experiment_metadata,
-        >>>                                              normal_read=True)
+        >>>                                              enable_sampling=True,
+        >>>                                              sampling_type='first_n_records',
+        >>>                                              sample_size_limit = 1GB,
+        >>>                                              experiment_metadata=experiment_metadata)
+
+        >>># read all data records in batches / no subsampling
+        >>> iterable_dataset = ExperimentIterableDataset(connection=connection,
+        >>>                                              enable_sampling=False,
+        >>>                                               experiment_metadata=experiment_metadata)
+
+        >>># stratified/random sampling
+        >>> iterable_dataset = ExperimentIterableDataset(connection=connection,
+        >>>                                              enable_sampling=True,
+        >>>                                              sampling_type='stratified',
+        >>>                                              sample_size_limit = 1GB,
+        >>>                                              experiment_metadata=experiment_metadata)
+
     """
 
     connection: Union[FlightConnection, LocalBatchReader] = None
@@ -52,8 +68,9 @@ class ExperimentIterableDataset(IterableDataset):
         self,
         connection: "DataConnection",
         experiment_metadata: dict = None,
-        with_subsampling: bool = False,
-        batch_size: int = 1073741824 if "32" in os.environ.get("MEM", "32") else 104857600,  # 1GB in Bytes,
+        enable_sampling: bool = True,
+        sample_size_limit: int = 1073741824 if "32" in os.environ.get("MEM", "32") else 104857600,  # 1GB in Bytes,
+        sampling_type: str = SamplingTypes.FIRST_N_RECORDS,
         binary_data: bool = False,
         number_of_batch_rows: int = None,
         stop_after_first_batch: bool = False,
@@ -61,15 +78,11 @@ class ExperimentIterableDataset(IterableDataset):
     ):
         super().__init__()
         self.experiment_metadata = experiment_metadata
-        self.with_subsampling = with_subsampling
-        self._wml_client = None
+        self.enable_sampling = enable_sampling
+        self._wml_client = getattr(connection, "_wml_client", None)
         self.binary_data = binary_data
-
-        # Note: turn on/off normal read for Flight Service (only one batch up to 1GB)
-        self.normal_read = False
-        if "normal_read" in kwargs:
-            self.normal_read = kwargs["normal_read"]
-        # --- end note
+        self.sampling_type = sampling_type
+        self.read_to_file = kwargs.get('read_to_file')
 
         self.authorized = self._wml_check_authorization()
 
@@ -81,11 +94,29 @@ class ExperimentIterableDataset(IterableDataset):
             dict_connection = connection
         # --- end note
 
+        # Note: backward compatibility after sampling refactoring #27255
+        if kwargs.get('with_sampling') or kwargs.get('normal_read'):
+            warn("The parameters with_sampling and normal_read in ExperimentIterableDataset are deprecated. "
+                 "Use enable_sampling and sampling_type instead.")
+            if kwargs.get('normal_read'):
+                self.enable_sampling = False
+            if kwargs.get('with_sampling'):
+                from ibm_watson_machine_learning.utils.autoai.enums import PredictionType
+                self.enable_sampling = True
+                if self.experiment_metadata.get("prediction_type") in [PredictionType.REGRESSION]:
+                    self.sampling_type = SamplingTypes.RANDOM
+                elif self.experiment_metadata.get("prediction_type") in [PredictionType.CLASSIFICATION,
+                                                                         PredictionType.BINARY,
+                                                                         PredictionType.MULTICLASS]:
+                    self.sampling_type = SamplingTypes.STRATIFIED
+        # --- end note
+
         # if number_of_batch_rows is provided, batch_size does not matter anymore
 
         if self.authorized:
             self.connection = FlightConnection(
                 headers=self._wml_client._get_headers() if self._wml_client is not None else self.experiment_metadata.get("headers"),
+                sampling_type=self.sampling_type,
                 label=self.experiment_metadata.get("prediction_column"),
                 learning_type=self.experiment_metadata.get("prediction_type"),
                 params=self.experiment_metadata,
@@ -94,7 +125,7 @@ class ExperimentIterableDataset(IterableDataset):
                 asset_id=dict_connection.get("location", {}).get("id"),
                 connection_id=dict_connection.get("connection", {}).get("id"),
                 data_location=dict_connection,
-                data_size_limit=batch_size,
+                data_size_limit=sample_size_limit,
                 flight_parameters=kwargs.get("flight_parameters", {}),
                 fallback_to_one_connection=kwargs.get(
                     "fallback_to_one_connection", True
@@ -111,7 +142,7 @@ class ExperimentIterableDataset(IterableDataset):
                 and "path" in dict_connection["location"]
             ):
                 self.connection = LocalBatchReader(
-                    file_path=dict_connection["location"]["path"], batch_size=batch_size
+                    file_path=dict_connection["location"]["path"], batch_size=sample_size_limit
                 )
 
             else:
@@ -121,7 +152,15 @@ class ExperimentIterableDataset(IterableDataset):
                 )
 
     def _wml_check_authorization(self) -> bool:
-        """Check if we can authorize with WML."""
+        """
+        Check if we can authorize with WML.
+        If the connection have wml_client initialized use it as an attribute.
+        Otherwise credentials should be provided in the experiment_metadata dictionary.
+        If they the client is properly initialized True will be returned.
+        """
+        if self._wml_client is not None:
+            return True
+
         if self.experiment_metadata is None:
             return False
 
@@ -178,19 +217,17 @@ class ExperimentIterableDataset(IterableDataset):
     def __iter__(self):
         """Iterate over Flight Dataset."""
         if self.authorized:
-            if self.normal_read:
+            if self.enable_sampling:
+                if self.sampling_type == SamplingTypes.FIRST_N_RECORDS:
+                    return self.connection.iterable_read()
+                else:
+                    self.connection.enable_subsampling = True
+                    return self.connection.iterable_read()
+            else:
                 if self.binary_data:
-                    return self.connection.read_binary_data()
+                    return self.connection.read_binary_data(read_to_file=self.read_to_file)
 
                 else:
                     return self.connection.read()
-
-            elif self.with_subsampling:
-                self.connection.enable_subsampling = True
-                return self.connection.iterable_read()
-
-            else:
-                return self.connection.iterable_read()
-
         else:
             return (batch for batch in self.connection)
