@@ -14,6 +14,7 @@
 
 import copy
 from typing import List, Union
+from warnings import warn
 
 from ibm_watson_machine_learning.preprocessing import DataJoinGraph
 from ibm_watson_machine_learning.utils.autoai.enums import (
@@ -171,7 +172,7 @@ class AutoAI(BaseExperiment):
                   cognito_transform_names: List['Transformers'] = None,
                   data_join_graph: 'DataJoinGraph' = None,
                   csv_separator: Union[List[str], str] = ',',
-                  excel_sheet: Union[str, int] = 0,
+                  excel_sheet: Union[str, int] = None,
                   encoding: str = 'utf-8',
                   positive_label: str = None,
                   data_join_only: bool = False,
@@ -264,8 +265,8 @@ class AutoAI(BaseExperiment):
             Default is ','.
 
         excel_sheet: Union[str, int], optional
-            Name or number of the excel sheet to use. Only use when xlsx file is an input.
-            Default is 0.
+            Name of the excel sheet to use. Only use when xlsx file is an input. Support for number of the sheet is deprecated.
+            By default first sheet is used.
 
         encoding: str, optional
             Encoding type for CSV training file.
@@ -408,6 +409,11 @@ class AutoAI(BaseExperiment):
         #     Default is SamplingTypes.FIRST_N_RECORDS.
         #     Supported only for IBM Cloud Pak® for Data 4.0.1 and above.
 
+        # Deprecation of excel_sheet as number:
+        if isinstance(excel_sheet, int):
+            warn(
+                message="Support for excel sheet as number of the sheet (int) is deprecated! Please set excel sheet with name of the sheet.")
+
         if prediction_type == PredictionType.FORECASTING and self._workspace.wml_client.ICP and \
                 (self._workspace.wml_client.wml_credentials['version'].startswith('2.5') or \
                         self._workspace.wml_client.wml_credentials['version'].startswith('3.0') or \
