@@ -298,8 +298,9 @@ class WMLEngine(BaseEngine):
                 'daub_runtime_ranking_power'] = self._auto_pipelines_parameters.get('daub_give_priority_to_runtime')
         # --- end note
 
-        # note: only pass excel_sheet when it is different than 0
-        if self._auto_pipelines_parameters.get('excel_sheet') != 0:
+        # note: only pass excel_sheet when it is different than 0 and is not None
+        if self._auto_pipelines_parameters.get('excel_sheet') and self._auto_pipelines_parameters.get(
+                'excel_sheet') != 0:
             self._wml_pipeline_metadata[self._wml_client.pipelines.ConfigurationMetaNames.DOCUMENT][
                 'pipelines'][0]['nodes'][0]['parameters'][
                 'excel_sheet'] = self._auto_pipelines_parameters.get('excel_sheet')
@@ -311,7 +312,8 @@ class WMLEngine(BaseEngine):
                 'pipelines'][0]['nodes'][0]['parameters'][
                 'test_input_file_separator'] = self._auto_pipelines_parameters.get('test_data_csv_separator')
 
-        if self._auto_pipelines_parameters.get('test_data_excel_sheet') != 0:
+        if self._auto_pipelines_parameters.get('test_data_excel_sheet') and self._auto_pipelines_parameters.get(
+                'test_data_excel_sheet') != 0:
             self._wml_pipeline_metadata[self._wml_client.pipelines.ConfigurationMetaNames.DOCUMENT][
                 'pipelines'][0]['nodes'][0]['parameters'][
                 'test_excel_sheet'] = self._auto_pipelines_parameters.get('test_data_excel_sheet')
