@@ -96,8 +96,8 @@ class RemoteAutoPipelines(BaseAutoPipelines):
             Default is ','.
 
     excel_sheet: Union[str, int], optional
-        Name or number of the excel sheet to use. Only use when xlsx file is an input.
-        Default is 0.
+        Name of the excel sheet to use. Only use when xlsx file is an input. Support for number of the sheet is deprecated.
+        By default first sheet is used.
 
     encoding: str, optional
             Encoding type for CSV training file.
@@ -139,7 +139,7 @@ class RemoteAutoPipelines(BaseAutoPipelines):
                  cognito_transform_names: List['Transformers'] = None,
                  data_join_graph: 'DataJoinGraph' = None,
                  csv_separator: Union[List[str], str] = ',',
-                 excel_sheet: Union[str, int] = 0,
+                 excel_sheet: Union[str, int] = None,
                  encoding: str = 'utf-8',
                  positive_label: str = None,
                  data_join_only: bool = False,
@@ -153,7 +153,7 @@ class RemoteAutoPipelines(BaseAutoPipelines):
                  text_columns_names=None,
                  n_parallel_data_connections=None,
                  test_data_csv_separator: Union[List[str], str] = ',',
-                 test_data_excel_sheet: Union[str, int] = 0,
+                 test_data_excel_sheet: Union[str, int] = None,
                  test_data_encoding: str = 'utf-8',
                  # sampling_type=None,  #TODO: Uncomment to add sampling_type support
                  categorical_imputation_strategy=None,
@@ -163,10 +163,15 @@ class RemoteAutoPipelines(BaseAutoPipelines):
                  fairness_info: dict = None,
                  retrain_on_holdout: bool = True,
                  **kwargs):
-        
+
         if data_join_graph is not None:
             data_join_graph.fairness_info = fairness_info
 
+        # Deprecation of excel_sheet as number:
+        if isinstance(excel_sheet, int) or isinstance(test_data_excel_sheet, int):
+            warn(
+                message="Support for excel sheet as number of the sheet (int) is deprecated! Please set excel sheet with name of the sheet.")
+
         self.params = {
             'name': name,
             'desc': desc if desc else '',
@@ -368,7 +373,8 @@ class RemoteAutoPipelines(BaseAutoPipelines):
         # to training DataConnections IDs/data_join_node_names
         if self.params['data_join_graph']:
             # note: If the location does not have path attribute it is either S3Location or DatabaseLocation
-            if any(filter(lambda x: x.type == DataConnectionTypes.CA and hasattr(x.location, "path"), training_data_reference)):
+            if any(filter(lambda x: x.type == DataConnectionTypes.CA and hasattr(x.location, "path"),
+                          training_data_reference)):
                 raise OBMForNFSIsNotSupported()
             # --- end note
 
@@ -427,14 +433,16 @@ class RemoteAutoPipelines(BaseAutoPipelines):
                             path="default_autoai_out")
                     )
 
-                else:   # set container output location when default DAta Asset is as a train ref
+                else:  # set container output location when default DAta Asset is as a train ref
                     training_results_reference = DataConnection(
                         location=ContainerLocation(path="default_autoai_out"))
 
-            elif isinstance(training_data_reference[0].location, ContainerLocation) and not self._workspace.wml_client.ICP:
+            elif isinstance(training_data_reference[0].location,
+                            ContainerLocation) and not self._workspace.wml_client.ICP:
                 training_results_reference = DataConnection(location=ContainerLocation(path="default_autoai_out"))
 
-            elif isinstance(training_data_reference[0].location, DatabaseLocation) and not self._workspace.wml_client.ICP:
+            elif isinstance(training_data_reference[0].location,
+                            DatabaseLocation) and not self._workspace.wml_client.ICP:
                 training_results_reference = DataConnection(location=ContainerLocation(path="default_autoai_out"))
 
             else:
@@ -461,7 +469,8 @@ class RemoteAutoPipelines(BaseAutoPipelines):
                     reason="Please specify Data Asset pointing to connection e.g. COS as an output.")
 
         # note: results can be stored only on FS or COS
-        if not isinstance(training_results_reference.location, (S3Location, FSLocation, AssetLocation, ContainerLocation)):
+        if not isinstance(training_results_reference.location,
+                          (S3Location, FSLocation, AssetLocation, ContainerLocation)):
             raise TypeError('Unsupported results location type. Results referance can be stored'
                             ' only on S3Location or FSLocation or AssetLocation.')
         # -- end
@@ -682,7 +691,8 @@ class RemoteAutoPipelines(BaseAutoPipelines):
                     preprocessing_pipeline = preprocessing_object.lale_pipeline
 
                     # note: fake fit for preprocessing pipeline to be able to predict
-                    preprocessing_pipeline = preprocessing_pipeline.fit(np.array([[1, 2, 3], [2, 3, 4]]), np.array([1, 2]))
+                    preprocessing_pipeline = preprocessing_pipeline.fit(np.array([[1, 2, 3], [2, 3, 4]]),
+                                                                        np.array([1, 2]))
                     return preprocessing_pipeline >> import_from_sklearn_pipeline(pipeline_model)
 
                 except MissingDataPreprocessingStep:
@@ -892,4 +902,3 @@ class RemoteAutoPipelines(BaseAutoPipelines):
         else:
             raise MissingDataPreprocessingStep(
                 reason="Cannot get preprocessed pipeline as preprocessing step was not performed.")
-
