@@ -32,8 +32,6 @@ from ibm_watson_machine_learning.utils.autoai.enums import DataConnectionTypes
 from ibm_watson_machine_learning.utils.autoai.errors import CannotReadSavedRemoteDataBeforeFit, WrongAssetType
 from ibm_watson_machine_learning.wml_client_error import ApiRequestFailure, WMLClientError
 from ibm_watson_machine_learning.utils.utils import is_lib_installed
-from ibm_watson_machine_learning.data_loaders.experiment import ExperimentDataLoader
-from ibm_watson_machine_learning.data_loaders.datasets.experiment import ExperimentIterableDataset
 
 if TYPE_CHECKING:
     from ibm_boto3 import resource
@@ -79,7 +77,7 @@ class BaseDataConnection(ABC):
         pass
 
     def _fill_experiment_parameters(self, prediction_type: str, prediction_column: str, holdout_size: float,
-                                    csv_separator: str = ',', excel_sheet: Union[str, int] = 0,
+                                    csv_separator: str = ',', excel_sheet: Union[str, int] = None,
                                     encoding: str = 'utf-8') -> None:
         """
         To be able to recreate a holdout split, this method need to be called.
@@ -374,8 +372,12 @@ class BaseDataConnection(ABC):
                         self.location.bucket = attachment_details['connection_path'].split('/')[1]
                         self.location.id = None
                         # Remove excel sheet name from connection_path if data asset is excel file:
-                        if self.auto_pipeline_params.get('excel_sheet') and \
-                                attachment_details['connection_path'].endswith("/"+str(self.auto_pipeline_params.get('excel_sheet'))):
+                        if '.xlsx/' in attachment_details['connection_path'] or '.xls/' in attachment_details['connection_path']:
+                            excel_sheet = attachment_details['connection_path'].split('/')[-1]
+                            # note: set recognized excel sheet in params
+                            if not self.auto_pipeline_params.get('excel_sheet'):
+                                self.auto_pipeline_params['excel_sheet'] = excel_sheet
+                            # end note
                             self.location.path = '/'.join(attachment_details['connection_path'].split('/')[2:-1])
                         else:
                             self.location.path = '/'.join(attachment_details['connection_path'].split('/')[2:])
@@ -796,10 +798,15 @@ class BaseDataConnection(ABC):
     def _download_data_from_flight_service(self,
                                            data_location: 'DataConnection',
                                            binary: bool = False,
+                                           read_to_file: str = None,
                                            flight_parameters: dict = None,
                                            headers: dict = None):
         is_lib_installed(lib_name='pyarrow', minimum_version='3.0.0', install=True)
 
+        # import the class only if flight scenario is enabled - do not import it in main import section
+        from ibm_watson_machine_learning.data_loaders.experiment import ExperimentDataLoader
+        from ibm_watson_machine_learning.data_loaders.datasets.experiment import ExperimentIterableDataset
+
         if flight_parameters is None:
             flight_parameters = {"num_partitions": 4}
 
@@ -818,10 +825,10 @@ class BaseDataConnection(ABC):
 
         iterable_dataset = ExperimentIterableDataset(
             connection=dict_connection,
-            with_subsampling=False,
+            enable_sampling=not binary,  # don't use sampling to read binary
             experiment_metadata=experiment_metadata,
-            normal_read=True,
             binary_data=binary,
+            read_to_file=read_to_file,
             flight_parameters=flight_parameters if flight_parameters is not None else {},
             fallback_to_one_connection=False,
             _wml_client=self._wml_client
@@ -840,29 +847,16 @@ class BaseDataConnection(ABC):
                                         headers: dict = None):
         is_lib_installed(lib_name='pyarrow', minimum_version='3.0.0', install=True)
 
+        # import the class only if flight scenario is enabled - do not import it in main import section
+        from ibm_watson_machine_learning.data_loaders.datasets.experiment import ExperimentIterableDataset
+
         if flight_parameters is None:
             flight_parameters = {"num_partitions": 1}
 
         dict_connection = data_location._to_dict()
 
         if remote_name:
-            if dict_connection.get('location', {}).get('path'):
-                dict_connection['location']['path'] = dict_connection['location']['path'] + '/' + remote_name
-                dict_connection['location']['path'] = dict_connection['location']['path'].replace('//', '/')
-            elif dict_connection.get('location', {}).get('file_name'):
-                actual_path = dict_connection['location']['file_name']
-                last_slash_index = actual_path.rfind('/') if '/' in actual_path else 0
-
-                if '.' in actual_path[last_slash_index:]:
-                    actual_path = actual_path[:-last_slash_index]
-
-                if actual_path:
-                    dict_connection['location']['path'] = actual_path + '/' + remote_name
-                    dict_connection['location']['path'] = dict_connection['location']['path'].replace('//', '/')
-                else:
-                    dict_connection['location']['path'] = remote_name
-            else:
-                dict_connection['location']['path'] = remote_name
+            dict_connection['location']['path'] = self._get_path_with_remote_name(dict_connection, remote_name)
         elif dict_connection.get('location', {}).get('file_name'):
             dict_connection['location']['path'] = dict_connection['location']['file_name']
 
@@ -897,3 +891,25 @@ class BaseDataConnection(ABC):
 
         else:
             iterable_dataset.write(file_path=file_path)
+
+    @staticmethod
+    def _get_path_with_remote_name(dict_connection: dict, remote_name: str) -> str:
+        if dict_connection.get('location', {}).get('path'):
+            updated_path = dict_connection['location']['path'] + '/' + remote_name
+            updated_path = updated_path.replace('//', '/')
+        elif dict_connection.get('location', {}).get('file_name'):
+            actual_path = dict_connection['location']['file_name']
+            last_slash_index = actual_path.rfind('/') if '/' in actual_path else 0
+
+            if '.' in actual_path[last_slash_index:]:
+                actual_path = actual_path[:-last_slash_index]
+
+            if actual_path:
+                updated_path = actual_path + '/' + remote_name
+                updated_path = updated_path.replace('//', '/')
+            else:
+                updated_path = remote_name
+        else:
+            updated_path = remote_name
+
+        return updated_path
