@@ -499,10 +499,11 @@ class DataConnection(BaseDataConnection):
     def read(self,
              with_holdout_split: bool = False,
              csv_separator: str = ',',
-             excel_sheet: Union[str, int] = 0,
+             excel_sheet: Union[str, int] = None,
              encoding: Optional[str] = 'utf-8',
              raw: Optional[bool] = False,
              binary: Optional[bool] = False,
+             read_to_file: Optional[str] = None,
              **kwargs) -> Union['DataFrame', Tuple['DataFrame', 'DataFrame'], bytes]:
         """
         Download dataset stored in remote data storage.
@@ -516,7 +517,7 @@ class DataConnection(BaseDataConnection):
             Separator / delimiter for CSV file, default is ','
 
         excel_sheet: Union[str, int], optional
-            Excel file sheet name to use, default is 0.
+            Excel file sheet name to use. Only use when xlsx file is an input. Support for number of the sheet is deprecated.
 
         encoding: str, optional
             Encoding type of the CSV
@@ -529,6 +530,10 @@ class DataConnection(BaseDataConnection):
             Indicates to retrieve data in binary mode. The result will be a python binary type variable.
             Default False.
 
+        read_to_file: str, optional
+            Stream read data to file under path specified as value of this parameter.
+            Use this parameter to prevent keeping data in-memory.
+
         Returns
         -------
         pandas.DataFrame contains dataset from remote data storage : Xy_train
@@ -575,6 +580,11 @@ class DataConnection(BaseDataConnection):
             bool((self._wml_client is not None or 'USER_ACCESS_TOKEN' in os.environ) and (
                     self._wml_client.ICP_40 or self._wml_client.CLOUD_PLATFORM_SPACES)))
 
+        # Deprecation of excel_sheet as number:
+        if isinstance(excel_sheet, int):
+            warn(
+                message="Support for excel sheet as number of the sheet (int) is deprecated! Please set excel sheet with name of the sheet.")
+
         flight_parameters = kwargs.get('flight_parameters', {})
 
         impersonate_header = kwargs.get('impersonate_header', None)
@@ -631,13 +641,15 @@ class DataConnection(BaseDataConnection):
                        f"if you are using historical runs, just call historical_optimizer.get_data_connections()")
 
         # note: allow to read data at any time
-        elif (('csv_separator' not in self.auto_pipeline_params and 'excel_sheet' not in self.auto_pipeline_params and
-               'encoding' not in self.auto_pipeline_params)
-              or csv_separator != ',' or excel_sheet != 0 or encoding != 'utf-8'):
+        elif (('csv_separator' not in self.auto_pipeline_params and 'encoding' not in self.auto_pipeline_params)
+              or csv_separator != ',' or encoding != 'utf-8'):
             self.auto_pipeline_params['csv_separator'] = csv_separator
-            self.auto_pipeline_params['excel_sheet'] = excel_sheet
             self.auto_pipeline_params['encoding'] = encoding
         # --- end note
+        # note: excel_sheet in params only if it is not None (not specified):
+        if excel_sheet:
+            self.auto_pipeline_params['excel_sheet'] = excel_sheet
+        # --- end note
 
         data = DataFrame()
 
@@ -656,6 +668,11 @@ class DataConnection(BaseDataConnection):
 
         elif self.type == DataConnectionTypes.DS:
             if use_flight and not self._obm:
+                from ibm_watson_machine_learning.utils.utils import is_lib_installed
+
+                is_lib_installed(lib_name='pyarrow', minimum_version='3.0.0', install=True)
+
+                from pyarrow.flight import FlightError
                 if self._check_if_connection_asset_is_s3():
                     # note: update flight parameters only if `connection_properties` was not set earlier
                     #       (e.x. by wml/autoi)
@@ -664,9 +681,10 @@ class DataConnection(BaseDataConnection):
                 try:
                     data = self._download_data_from_flight_service(data_location=self,
                                                                    binary=binary,
+                                                                   read_to_file=read_to_file,
                                                                    flight_parameters=flight_parameters,
                                                                    headers=headers)
-                except ConnectionError as flight_connection_error:
+                except (ConnectionError, FlightError) as flight_connection_error:
                     # note: try to download normal data asset directly from cams - to keep backward compatibility
                     if self._wml_client and not self._check_if_connection_asset_is_s3():
                         import warnings
@@ -709,6 +727,7 @@ class DataConnection(BaseDataConnection):
 
                     data = self._download_data_from_flight_service(data_location=self,
                                                                    binary=binary,
+                                                                   read_to_file=read_to_file,
                                                                    flight_parameters=flight_parameters,
                                                                    headers=headers)
 
@@ -730,6 +749,7 @@ class DataConnection(BaseDataConnection):
 
                 data = self._download_data_from_flight_service(data_location=self,
                                                                binary=binary,
+                                                               read_to_file=read_to_file,
                                                                flight_parameters=flight_parameters,
                                                                headers=headers)
 
@@ -763,12 +783,10 @@ class DataConnection(BaseDataConnection):
 
                     data = self._download_data_from_flight_service(data_location=self,
                                                                    binary=binary,
+                                                                   read_to_file=read_to_file,
                                                                    flight_parameters=flight_parameters,
                                                                    headers=headers)
 
-        if isinstance(data, DataFrame) and 'Unnamed: 0' in data.columns.tolist():
-            data.drop(['Unnamed: 0'], axis=1, inplace=True)
-
         if binary:
             return data
 
@@ -833,10 +851,11 @@ class DataConnection(BaseDataConnection):
             if self._check_if_connection_asset_is_s3():
                 # do not try Flight if we are on the cloud
                 if self._wml_client is not None and not self._wml_client.ICP and not use_flight:  # CLOUD
+                    updated_remote_name = self._get_path_with_remote_name(self._to_dict(), remote_name)
                     cos_resource_client = self._init_cos_client()
                     if isinstance(data, str):
                         with open(data, "rb") as file_data:
-                            cos_resource_client.Object(self.location.bucket, remote_name).upload_fileobj(
+                            cos_resource_client.Object(self.location.bucket, updated_remote_name).upload_fileobj(
                                 Fileobj=file_data)
 
                     elif isinstance(data, DataFrame):
@@ -846,7 +865,7 @@ class DataConnection(BaseDataConnection):
                         buffer.seek(0)
 
                         with buffer as f:
-                            cos_resource_client.Object(self.location.bucket, remote_name).upload_fileobj(
+                            cos_resource_client.Object(self.location.bucket, updated_remote_name).upload_fileobj(
                                 Fileobj=io.BytesIO(bytes(f.read().encode())))
 
                     else:
@@ -1206,7 +1225,7 @@ class AssetLocation(BaseLocation):
     def _get_attachment_details(self, client) -> dict:
         asset_details = client.data_assets.get_details(self.id)
 
-        if 'attachment_id' in asset_details['metadata']:
+        if 'attachment_id' in asset_details.get('metadata'):
             attachment_id = asset_details['metadata']['attachment_id']
 
         else:
