@@ -15,9 +15,12 @@ import threading
 import queue
 import pandas as pd
 
+from contextlib import nullcontext
 from functools import partial
 from typing import List, Optional, Iterable, Generator
 
+from ibm_watson_machine_learning.utils.autoai.errors import InvalidSamplingType
+from ibm_watson_machine_learning.utils.autoai.enums import PredictionType, SamplingTypes
 from ibm_watson_machine_learning.wml_client_error import (
     DataStreamError, WrongLocationProperty, WrongFileLocation, SpaceIDandProjectIDCannotBeNone)
 from ibm_watson_machine_learning.utils.utils import is_lib_installed, prepare_interaction_props_for_cos
@@ -60,8 +63,13 @@ class FlightConnection:
     label: string, required
         Y column name. It is required for subsampling.
 
+    sampling_type: str, required
+        A sampling strategy required of choice.
+
     learning_type: string, required
         Type of the dataset: 'classification', 'multiclass', 'regression'. Needed for resampling.
+        If value is equal to None 'first_n_records' strategy will be used no mather what is specified in
+        'sampling_type'.
 
     data_location: dict, optional
         Data location information passed by user.
@@ -90,6 +98,7 @@ class FlightConnection:
 
     def __init__(self,
                  headers: dict,
+                 sampling_type: str,
                  label: str,
                  learning_type: str,
                  params: dict,
@@ -127,6 +136,7 @@ class FlightConnection:
         self.callback = callback if callback is not None else FakeCallback()
 
         # Note: Variables from AutoAI training
+        self.sampling_type = sampling_type
         self.label = label
         self.learning_type = learning_type
         self.params = params
@@ -247,7 +257,7 @@ class FlightConnection:
                 return TokenClientAuthHandler(token=auth_json_str, _type='json_string', impersonate=True)
             else:
                 return TokenClientAuthHandler(token=self.headers.get('Authorization', 'Bearer  ').split('Bearer ')[-1],
-                                          _type='Bearer')
+                                              _type='Bearer')
 
         elif 'Basic' in self.headers.get('Authorization', ''):
             return TokenClientAuthHandler(token=self.headers.get('Authorization', 'Basic  ').split('Basic ')[-1],
@@ -570,43 +580,43 @@ class FlightConnection:
         def start_reading_threads():
             # Note: endpoints are created by Flight Service based on number of partitions configured
             # one endpoint serves multiple mini batches of the data
-
-            if self.enable_subsampling:
-                if self.learning_type == 'regression':
-                    subsampling_thread = threading.Thread(target=self.regression_random_sampling, args=(self.label,))
+            try:
+                if self.enable_subsampling:
+                    subsampling_thread = threading.Thread(target=self._get_sampling_strategy(), args=(self.label,))
+                    subsampling_thread.start()
 
                 else:
-                    subsampling_thread = threading.Thread(target=self.stratified_subsampling, args=(self.label,))
+                    normal_read_thread = threading.Thread(target=self.normal_read)
+                    normal_read_thread.start()
 
-                subsampling_thread.start()
+                for n, endpoints in enumerate(self.get_endpoints()):
+                    self.max_flight_batch_number = len(endpoints)  # when flight does not want to open more endpoints
+                    threads = []
+                    sequences.append(threads)
 
-            else:
-                normal_read_thread = threading.Thread(target=self.normal_read)
-                normal_read_thread.start()
+                    for i, endpoint in enumerate(endpoints):
+                        reading_thread = threading.Thread(target=self._get_data, args=(i, endpoint))
+                        threads.append(reading_thread)
+                        logger.debug(f"R: Starting batch reading thread: {i}, sequence: {n}...")
+                        reading_thread.start()
 
-            for n, endpoints in enumerate(self.get_endpoints()):
-                self.max_flight_batch_number = len(endpoints)  # when flight does not want to open more endpoints
-                threads = []
-                sequences.append(threads)
+            except Exception as e:
+                self.row_size = -1  # further we raise an error to finish thread
+                raise e
+            finally:
 
-                for i, endpoint in enumerate(endpoints):
-                    reading_thread = threading.Thread(target=self._get_data, args=(i, endpoint))
-                    threads.append(reading_thread)
-                    logger.debug(f"R: Starting batch reading thread: {i}, sequence: {n}...")
-                    reading_thread.start()
+                for n, sequence in enumerate(sequences):
+                    for i, thread in enumerate(sequence):
+                        logger.debug(f"R: Joining batch reading thread {i}, sequence: {n}...")
+                        thread.join()
 
-            for n, sequence in enumerate(sequences):
-                for i, thread in enumerate(sequence):
-                    logger.debug(f"R: Joining batch reading thread {i}, sequence: {n}...")
-                    thread.join()
+                self.q.put_nowait((-1, -1))  # send close queue message (stop reading logical batches)
 
-            self.q.put_nowait((-1, -1))  # send close queue message (stop reading logical batches)
+                if self.enable_subsampling:
+                    subsampling_thread.join()
 
-            if self.enable_subsampling:
-                subsampling_thread.join()
-
-            else:
-                normal_read_thread.join()
+                else:
+                    normal_read_thread.join()
 
         try:
             start_reading_threads()
@@ -616,7 +626,7 @@ class FlightConnection:
                 logger.debug(f"R: Partitions Thread Errors: {self.threads_exceptions}")
 
                 for msg in self.threads_exceptions:
-                    if "CSV/parquet" in msg:
+                    if "Data could not be read" in msg:
                         raise TypeError(msg)
 
             if self.enable_subsampling:
@@ -665,7 +675,7 @@ class FlightConnection:
 
         while True:
             if self.row_size == -1:
-                raise TypeError("Data is not of CSV/parquet type. Try to use a binary read mode.")
+                raise TypeError("Data could not be read. Try to use a binary read mode.")
 
             if self.row_size != 0:
                 if _type == 'data':
@@ -757,7 +767,6 @@ class FlightConnection:
         logical_batch = []
         mini_batch_counter = 0
         threads_finished = 0
-        msg = "Data is not of CSV/parquet type. Try to use a binary read mode."
 
         while True:
             try:
@@ -877,6 +886,10 @@ class FlightConnection:
             if infer_schema:
                 command['interaction_properties']['infer_schema'] = "true"
 
+        # Property 'infer_as_varchar` needs to be false, when 'infer_schema' is true
+        if command['interaction_properties'].get('infer_schema', "false") == "true":
+            command['interaction_properties'].update({'infer_as_varchar': "false"})
+
         # Git based project assets property
         if self.data_location is not None and self.data_location['location'].get('userfs'):
             command['interaction_properties'].update({'userfs': True})
@@ -890,7 +903,7 @@ class FlightConnection:
 
         return [json.dumps(command)]
 
-    def read_binary_data(self) -> None:
+    def read_binary_data(self, read_to_file=None) -> None:
         """Try to read data from flight service using the 'read_raw' parameter. This will allow to fetch binary data.
             Binary read should be used for small data, like json files, zip files etc. not for the big datasets as
             each data batch is joined to the previous one in-memory.
@@ -901,18 +914,26 @@ class FlightConnection:
             self.flight_parameters['num_partitions'] = 1
             self.max_flight_batch_number = 1
 
-        binary_data_array = []
-        for n, endpoints in enumerate(self.get_endpoints()):
-            for i, endpoint in enumerate(endpoints):
-                reader = self.flight_client.do_get(endpoint.ticket)
-                try:
-                    while True:
-                        mini_batch, metadata = reader.read_chunk()
-                        binary_data_array.extend(mini_batch.columns[0].tolist())
-                except StopIteration:
-                    pass
-        binary_data_container = b''.join(binary_data_array)
-        yield binary_data_container
+        cm = open(read_to_file, 'wb') if read_to_file else nullcontext()
+        with cm as sink:
+            binary_data_array = []
+            for n, endpoints in enumerate(self.get_endpoints()):
+                for i, endpoint in enumerate(endpoints):
+                    reader = self.flight_client.do_get(endpoint.ticket)
+                    try:
+                        while True:
+                            mini_batch, metadata = reader.read_chunk()
+                            if read_to_file:
+                                sink.write(b''.join(mini_batch.columns[0].tolist()))
+                            else:
+                                binary_data_array.extend(mini_batch.columns[0].tolist())
+                    except StopIteration:
+                        pass
+        if read_to_file:
+            return [read_to_file]
+        else:
+            binary_data_container = b''.join(binary_data_array)
+            yield binary_data_container
 
     def write_binary_data(self, file_path: str) -> None:
         """Write data in 16MB binary data blocks. 16MB upper limit is set by the Flight Service.
@@ -964,3 +985,22 @@ class FlightConnection:
         self.flight_client.authenticate(self.authenticate())
         writer, reader = self.flight_client.do_put(flight.FlightDescriptor.for_command(commands[0]), schema)
         return writer
+
+
+    def _get_sampling_strategy(self):
+        """
+        Return sampling strategy for given sampling and learning type.
+        """
+        random_sampling_pred_types = (
+            PredictionType.REGRESSION,
+        )
+        stratified_sampling_pred_types = (
+            PredictionType.CLASSIFICATION, PredictionType.BINARY, PredictionType.MULTICLASS
+        )
+
+        if self.sampling_type == SamplingTypes.RANDOM and self.learning_type in random_sampling_pred_types:
+            return self.regression_random_sampling
+        elif self.sampling_type == SamplingTypes.STRATIFIED and self.learning_type in stratified_sampling_pred_types:
+            return self.stratified_subsampling
+        else:
+            raise InvalidSamplingType(self.sampling_type, self.learning_type)
