@@ -13,7 +13,7 @@
 #  limitations under the License.
 
 from __future__ import print_function
-import requests
+import ibm_watson_machine_learning._wrappers.requests as requests
 from ibm_watson_machine_learning.utils import STR_TYPE, STR_TYPE_NAME, docstring_parameter, meta_props_str_conv
 import os
 import json
@@ -99,29 +99,10 @@ class Import(WMLResource):
         else:
             params.update({"project_id": project_id})
 
-        from datetime import datetime
-        # start_time = datetime.now()
-
-        if not self._ICP:
-            creation_response = requests.post(href,
-                                              params=params,
-                                              headers=self._client._get_headers(content_type='application/zip'),
-                                              data=data)
-                                              # files=file_handler)
-        else:
-            creation_response = requests.post(href,
-                                              params=params,
-                                              headers=self._client._get_headers(content_type='application/zip'),
-                                              data=data,
-                                              # files=file_handler,
-                                              verify=False)
-
-        # end_time = datetime.now()
-        #
-        # dt = end_time - start_time
-        # ms = (dt.days * 24 * 60 * 60 + dt.seconds) * 1000 + dt.microseconds / 1000.0
-        #
-        # print("Time taken to get response from import api call in ms: {}".format(ms))
+        creation_response = requests.post(href,
+                                          params=params,
+                                          headers=self._client._get_headers(content_type='application/zip'),
+                                          data=data)
 
         details = self._handle_response(expected_status_code=202,
                                         operationName=u'import start',
@@ -191,15 +172,9 @@ class Import(WMLResource):
         else:
             params.update({"project_id": project_id})
 
-        if not self._ICP:
-            cancel_response = requests.delete(href,
-                                              params=params,
-                                              headers=self._client._get_headers())
-        else:
-            cancel_response = requests.delete(href,
-                                              params=params,
-                                              headers=self._client._get_headers(),
-                                              verify=False)
+        cancel_response = requests.delete(href,
+                                          params=params,
+                                          headers=self._client._get_headers())
 
         details = self._handle_response(expected_status_code=204,
                                         operationName=u'cancel import',
@@ -254,15 +229,9 @@ class Import(WMLResource):
         else:
             params.update({'project_id': project_id})
 
-        if not self._ICP:
-            delete_response = requests.delete(href,
-                                              params=params,
-                                              headers=self._client._get_headers())
-        else:
-            delete_response = requests.delete(href,
-                                              params=params,
-                                              headers=self._client._get_headers(),
-                                              verify=False)
+        delete_response = requests.delete(href,
+                                          params=params,
+                                          headers=self._client._get_headers())
 
         details = self._handle_response(expected_status_code=204,
                                         operationName=u'delete import job',
