@@ -42,16 +42,14 @@ class ServiceInstanceNewPlan:
             # self._wml_credentials[u'instance_id'] = "999"
 
         # This is used in connections.py
-        self._href_definitions = HrefDefinitions(self._wml_credentials,
+        self._href_definitions = HrefDefinitions(self._client,
                                                  self._client.CLOUD_PLATFORM_SPACES,
                                                  self._client.PLATFORM_URL,
                                                  self._client.CAMS_URL,
-                                                 self._client.ICP_PLATFORM_SPACES,
-                                                 git_based_project=self._client.project_type == "local_git_storage"
-                                                 )
+                                                 self._client.ICP_PLATFORM_SPACES)
 
         self._client.wml_token = self._create_token()
-        self._logger.info(u'Successfully prepared token: ' + self._client.wml_token)
+        # self._logger.info(u'Successfully prepared token: ' + self._client.wml_token)
         # ml_repository_client is initialized in repo
         self.details = None
 
