@@ -213,18 +213,11 @@ class ModelDefinition(WMLResource):
         paramvalue = self._client._params()
 
         try:
-            if not self._ICP:
-                creation_response = requests.post(
-                     self._client.service_instance._href_definitions.get_model_definition_assets_href(),
-                     params=paramvalue,
-                     headers=self._client._get_headers(),
-                     json=document)
-            else:
-                creation_response = requests.post(
-                    self._client.service_instance._href_definitions.get_model_definition_assets_href(),
-                    params=paramvalue,
-                    headers=self._client._get_headers(),
-                    json=document)
+            creation_response = requests.post(
+                 self._client.service_instance._href_definitions.get_model_definition_assets_href(),
+                 params=paramvalue,
+                 headers=self._client._get_headers(),
+                 json=document)
 
             model_definition_details = self._handle_response(201, u'creating new model_definition', creation_response)
 
@@ -238,18 +231,13 @@ class ModelDefinition(WMLResource):
             files = {'file': open(model_definition, 'rb')}
             if creation_response.status_code == 201:
                 model_definition_id = model_definition_details['metadata']['asset_id']
-                if not self._ICP:
-                    attachment_response = requests.post(
-                        model_definition_attachment_url,
-                        params=paramvalue,
-                        headers=self._client._get_headers(),
-                        json=model_definition_attachment_def)
-                else:
-                    attachment_response = requests.post(
-                         model_definition_attachment_url,
-                         params=paramvalue,
-                         headers=self._client._get_headers(),
-                         json=model_definition_attachment_def)
+
+                attachment_response = requests.post(
+                    model_definition_attachment_url,
+                    params=paramvalue,
+                    headers=self._client._get_headers(),
+                    json=model_definition_attachment_def)
+
                 attachment_details = self._handle_response(201, u'creating new attachment', attachment_response)
                 if attachment_response.status_code == 201:
                     attachment_id = attachment_details['attachment_id']
@@ -271,16 +259,10 @@ class ModelDefinition(WMLResource):
                         put_response = requests.put(model_definition_attachment_put_url,
                                                     files=files)
                     if put_response.status_code == 201 or put_response.status_code == 200:
-                        complete_url = self._client.service_instance._href_definitions.get_attachment_href(model_definition_id, attachment_id) \
-                                       + "/complete"
-                        if not self._ICP:
-                            complete_response = requests.post( self._client.service_instance._href_definitions.get_attachment_complete_href(model_definition_id, attachment_id),
-                                                              params=paramvalue,
-                                                              headers=self._client._get_headers())
-                        else:
-                            complete_response = requests.post(complete_url,
-                                                              params=paramvalue,
-                                                              headers=self._client._get_headers())
+
+                        complete_response = requests.post( self._client.service_instance._href_definitions.get_attachment_complete_href(model_definition_id, attachment_id),
+                                                          params=paramvalue,
+                                                          headers=self._client._get_headers())
 
                         if complete_response.status_code == 200:
                             response = self._get_required_element_from_response(model_definition_details)
@@ -349,19 +331,13 @@ class ModelDefinition(WMLResource):
         ModelDefinition._validate_type(modeldef_uid, u'model_definition_uid', STR_TYPE, False)
 
         url = self._client.service_instance._href_definitions.get_model_definition_assets_href() + u'/' + modeldef_uid
-        paramvalue = self._client._params()
-        if not self._ICP:
-            response_get = requests.get(
-                url,
-                params=self._client._params(),
-                headers=self._client._get_headers()
-            )
-        else:
-            response_get = requests.get(
-                url,
-                params=paramvalue,
-                headers=self._client._get_headers()
-            )
+
+        response_get = requests.get(
+            url,
+            params=self._client._params(),
+            headers=self._client._get_headers()
+        )
+
         if response_get.status_code == 200:
             get_model_definition_details = self._handle_response(200, op_name, response_get)
             response = self._get_required_element_from_response(get_model_definition_details)
@@ -503,10 +479,8 @@ class ModelDefinition(WMLResource):
         paramvalue = self._client._params()
 
         model_definition_endpoint = self._client.service_instance._href_definitions.get_model_definition_assets_href() + "/" + model_definition_uid
-        if not self._ICP:
-            response_delete = requests.delete(model_definition_endpoint, params=paramvalue, headers=self._client._get_headers())
-        else:
-            response_delete = requests.delete(model_definition_endpoint, params=paramvalue, headers=self._client._get_headers())
+
+        response_delete = requests.delete(model_definition_endpoint, params=paramvalue, headers=self._client._get_headers())
 
         return self._handle_response(204, u'Model definition deletion', response_delete, False)
 
@@ -537,10 +511,8 @@ class ModelDefinition(WMLResource):
         ModelDefinition._validate_type(model_definition_uid, u'model_definition_uid', STR_TYPE, True)
         paramvalue = self._client._params()
         model_definition_endpoint = self._client.service_instance._href_definitions.get_model_definition_assets_href() + "/" + model_definition_uid
-        if not self._ICP:
-            response_delete = requests.delete(model_definition_endpoint, params=paramvalue, headers=self._client._get_headers())
-        else:
-            response_delete = requests.delete(model_definition_endpoint, params=paramvalue, headers=self._client._get_headers())
+
+        response_delete = requests.delete(model_definition_endpoint, params=paramvalue, headers=self._client._get_headers())
 
     def _get_required_element_from_response(self, response_data):
 
@@ -659,10 +631,8 @@ class ModelDefinition(WMLResource):
                 "limit": limit
             }
 
-        if not self._ICP:
-            response = requests.post(href, params=self._client._params(), headers=self._client._get_headers(),json=data)
-        else:
-            response = requests.post(href, params=self._client._params(), headers=self._client._get_headers(),json=data)
+        response = requests.post(href, params=self._client._params(), headers=self._client._get_headers(), json=data)
+
         self._handle_response(200, u'model_definition assets', response)
         asset_details = self._handle_response(200, u'model_definition assets', response)["results"]
         model_def_values = [
@@ -875,16 +845,10 @@ class ModelDefinition(WMLResource):
                 entity_patch_url = self._client.service_instance._href_definitions.get_asset_href(model_definition_id) + \
                                    '/attributes/wml_model_definition'
 
-                if not self._ICP:
-                    response_patch = requests.patch(entity_patch_url,
-                                                    json=entity_patch_payload,
-                                                    params=self._client._params(),
-                                                    headers=self._client._get_headers())
-                else:
-                    response_patch = requests.patch(entity_patch_url,
-                                                    json=entity_patch_payload,
-                                                    params=self._client._params(),
-                                                    headers=self._client._get_headers())
+                response_patch = requests.patch(entity_patch_url,
+                                                json=entity_patch_payload,
+                                                params=self._client._params(),
+                                                headers=self._client._get_headers())
 
                 updated_details = self._handle_response(200, u'script patch', response_patch)
 
@@ -1120,10 +1084,7 @@ class ModelDefinition(WMLResource):
             params.update( {
                 "limit": limit
             })
-        if not self._ICP:
-            response = requests.get(href, params, headers=self._client._get_headers())
-        else:
-            response = requests.get(href, params=params, headers=self._client._get_headers())
+        response = requests.get(href, params=params, headers=self._client._get_headers())
         self._handle_response(200, u'model_definition revision assets', response)
         asset_details = self._handle_response(200, u'model_definition revision assets', response)["results"]
         model_def_values = [
