@@ -42,6 +42,8 @@ def process_heartbeat(client, **kwargs):
 
         if service_version.startswith("4.0"):
             version_details = service_version.split('-')
+            if version_details[1] >= "202203":
+                return "cpd408"
             if version_details[1] >= "202202":
                 return "cpd407"
             if version_details[1] >= "202112":
@@ -91,7 +93,7 @@ def choose_software_version(software_spec):
 
 def check_python_version(platform_env):
     py_version = platform.python_version()
-    if platform_env != "cloud" and platform_env != "cpd407":
+    if platform_env != "cloud" and platform_env != "cpd407" and platform_env != "cpd408":
         if not py_version.startswith("3.7.") and not py_version.startswith("3.8."):
             raise Exception("Python version {} is not supported for Federated Learning. "
                             "Parties must use a supported Python version to train the model. "
@@ -121,6 +123,7 @@ class Party(WMLResource):
         'cpd403': "/cpd403/ibmfl",
         'cpd406': "/cpd406/ibmfl",
         'cpd407': "/cpd406/ibmfl",
+        'cpd408': "/cpd406/ibmfl",
         'py38-tf24-pt17-sk23': "/py38-tf24-pt17-sk23/ibmfl", #default
         'py39-tf27-pt110-sk10': "/py39-tf27-pt110-sk10/ibmfl"
     }
