@@ -59,13 +59,9 @@ class Script(WMLResource):
         """
         Script._validate_type(script_uid, u'script_uid', STR_TYPE, True)
 
+        response = requests.get(self._client.service_instance._href_definitions.get_data_asset_href(script_uid), params=self._client._params(),
+                                headers=self._client._get_headers())
 
-        if not self._ICP:
-            response = requests.get(self._client.service_instance._href_definitions.get_data_asset_href(script_uid), params=self._client._params(),
-                                    headers=self._client._get_headers())
-        else:
-            response = requests.get(self._client.service_instance._href_definitions.get_data_asset_href(script_uid), params=self._client._params(),
-                                      headers=self._client._get_headers())
         if response.status_code == 200:
             response = self._get_required_element_from_response(self._handle_response(200, u'get asset details', response))
 
@@ -415,20 +411,13 @@ class Script(WMLResource):
                         )
                     if put_response.status_code == 201 or put_response.status_code == 200:
                         # Step4: Complete attachment
-                        if not self._ICP:
-                            complete_response = requests.post(
-                                # self._client.service_instance._href_definitions.get_attachment_href(asset_id,attachment_id)+"/complete",
-                                self._client.service_instance._href_definitions.get_attachment_complete_href(asset_id, attachment_id),
-                                headers=self._client._get_headers(),
-                                params = self._client._params()
+                        complete_response = requests.post(
+                            self._client.service_instance._href_definitions.get_attachment_complete_href(asset_id, attachment_id),
+                            headers=self._client._get_headers(),
+                            params = self._client._params()
+
+                        )
 
-                            )
-                        else:
-                            complete_response = requests.post(
-                                self._client.service_instance._href_definitions.get_attachment_href(asset_id,attachment_id)+"/complete",
-                                headers=self._client._get_headers(),
-                                params=self._client._params()
-                            )
                         if complete_response.status_code == 200:
                             print("SUCCESS")
                             return self._get_required_element_from_response(asset_details)
@@ -475,10 +464,8 @@ class Script(WMLResource):
         if limit is not None:
             data.update({"limit": limit})
 
-        if not self._ICP:
-            response = requests.post(href, params=self._client._params(), headers=self._client._get_headers(),json=data)
-        else:
-            response = requests.post(href, params=self._client._params(), headers=self._client._get_headers(),json=data)
+        response = requests.post(href, params=self._client._params(), headers=self._client._get_headers(),json=data)
+
         self._handle_response(200, u'list assets', response)
         asset_details = self._handle_response(200, u'list assets', response)["results"]
         space_values = [
@@ -558,12 +545,10 @@ class Script(WMLResource):
                 raise WMLClientError(u'Saving data asset with artifact_url: \'{}\'  to local file failed.'.format(filename), e)
         else:
             attachment_id = asset_details["attachments"][0]["id"]
-            if not self._ICP:
-                response = requests.get(self._client.service_instance._href_definitions.get_attachment_href(asset_uid,attachment_id), params=params,
-                                        headers=self._client._get_headers())
-            else:
-                response = requests.get(self._client.service_instance._href_definitions.get_attachment_href(asset_uid,attachment_id), params=params,
-                                          headers=self._client._get_headers())
+
+            response = requests.get(self._client.service_instance._href_definitions.get_attachment_href(asset_uid,attachment_id), params=params,
+                                    headers=self._client._get_headers())
+
             if response.status_code == 200:
                 attachment_signed_url = response.json()["url"]
                 if 'connection_id' in asset_details["attachments"][0]:
@@ -777,32 +762,20 @@ class Script(WMLResource):
             if meta_patch_payload:
                 meta_patch_url = self._client.service_instance._href_definitions.get_asset_href(script_uid)
 
-                if not self._ICP:
-                    response_patch = requests.patch(meta_patch_url,
-                                                    json=meta_patch_payload,
-                                                    params=self._client._params(),
-                                                    headers=self._client._get_headers())
-                else:
-                    response_patch = requests.patch(meta_patch_url,
-                                                    json=meta_patch_payload,
-                                                    params=self._client._params(),
-                                                    headers=self._client._get_headers())
+                response_patch = requests.patch(meta_patch_url,
+                                                json=meta_patch_payload,
+                                                params=self._client._params(),
+                                                headers=self._client._get_headers())
 
                 updated_details = self._handle_response(200, u'script patch', response_patch)
 
             if entity_patch_payload:
                 entity_patch_url = self._client.service_instance._href_definitions.get_asset_href(script_uid) + '/attributes/script'
 
-                if not self._ICP:
-                    response_patch = requests.patch(entity_patch_url,
-                                                    json=entity_patch_payload,
-                                                    params=self._client._params(),
-                                                    headers=self._client._get_headers())
-                else:
-                    response_patch = requests.patch(entity_patch_url,
-                                                    json=entity_patch_payload,
-                                                    params=self._client._params(),
-                                                    headers=self._client._get_headers())
+                response_patch = requests.patch(entity_patch_url,
+                                                json=entity_patch_payload,
+                                                params=self._client._params(),
+                                                headers=self._client._get_headers())
 
                 updated_details = self._handle_response(200, u'script patch', response_patch)
 
@@ -895,12 +868,9 @@ class Script(WMLResource):
             raise WMLClientError(
                 u'Cannot delete script that has existing deployments. Please delete all associated deployments and try again')
 
-        if not self._ICP:
-            response = requests.delete(self._client.service_instance._href_definitions.get_asset_href(asset_uid), params=self._client._params(),
-                                    headers=self._client._get_headers())
-        else:
-            response = requests.delete(self._client.service_instance._href_definitions.get_asset_href(asset_uid), params=self._client._params(),
-                                      headers=self._client._get_headers())
+        response = requests.delete(self._client.service_instance._href_definitions.get_asset_href(asset_uid), params=self._client._params(),
+                                headers=self._client._get_headers())
+
         if response.status_code == 200:
             return self._get_required_element_from_response(response.json())
         else:
@@ -1092,12 +1062,8 @@ class Script(WMLResource):
     def _delete(self, asset_uid):
         Script._validate_type(asset_uid, u'asset_uid', STR_TYPE, True)
 
-        if not self._ICP:
-            response = requests.delete(self._client.service_instance._href_definitions.get_asset_href(asset_uid), params=self._client._params(),
-                                       headers=self._client._get_headers())
-        else:
-            response = requests.delete(self._client.service_instance._href_definitions.get_asset_href(asset_uid), params=self._client._params(),
-                                       headers=self._client._get_headers())
+        response = requests.delete(self._client.service_instance._href_definitions.get_asset_href(asset_uid), params=self._client._params(),
+                                   headers=self._client._get_headers())
 
     def _get_required_element_from_response(self, response_data):
 
