@@ -312,7 +312,8 @@ class VisualizationTypes:
 class SamplingTypes:
     """Types of training data sampling"""
     FIRST_N_RECORDS = 'first_n_records'
-    RANDOM_STRATIFIED = 'random_stratified'
+    RANDOM = 'random'
+    STRATIFIED = 'stratified'
 
 
 class ImputationStrategy(Enum):
@@ -327,4 +328,4 @@ class ImputationStrategy(Enum):
     CUBIC = 'cubic'
     PREVIOUS = 'previous'
     NEXT = 'next'
-    NO_IMPUTATION = 'no_imputation'
\ No newline at end of file
+    NO_IMPUTATION = 'no_imputation'
