@@ -727,7 +727,8 @@ def prepare_interaction_props_for_cos(source_params: dict, file_name: str) -> di
 
     if ".xls" in file_name or ".xlsx" in file_name:
         file_format = "excel"
-        interaction_properties["sheet_name"] = str(source_params.get("excel_sheet", 0))
+        if source_params.get("excel_sheet"):
+            interaction_properties["sheet_name"] = str(source_params.get("excel_sheet"))
 
     elif '.csv' in file_name:
         if encoding is not None:
