@@ -717,7 +717,7 @@ class WMLResource:
                     # STEP 3d.
                     # Mark attachment complete
                     complete_response = requests.post(
-                        self._client.service_instance._href_definitions.get_attachment_href(asset_id, attachment_id) + "/complete",
+                        self._client.service_instance._href_definitions.get_attachment_complete_href(asset_id, attachment_id),
                         headers=self._client._get_headers(),
                         params=self._client._params()
                     )
